@@ -54,9 +54,9 @@
 
 /////////////////////////////////////////////////////////////////////////////
 
-   Why are we not using QT signal/slots?
+   Why are we not using TQt signal/slots?
 
-   First the idea of using qt for connecting interfaces is very nice, as the
+   First the idea of using tqt for connecting interfaces is very nice, as the
    signal/slot model is well known and hopefully properly implemented.
 
    But there are some problems:
@@ -78,13 +78,13 @@
      forget to connect signals/slots of that interfaces.
 
    - Aggregation of multiple interface implementations (each one is an TQObject)
-     is not possible because qt does not allow multiple inheritance of TQObjects
+     is not possible because tqt does not allow multiple inheritance of TQObjects
 
 /////////////////////////////////////////////////////////////////////////////
 
    What about our own solution?
 
-   Well, it eliminates at least the qt-problems explained above. But first we
+   Well, it eliminates at least the tqt-problems explained above. But first we
    need a common mechanism to manage interface connections. This functionality
    can be provided by a common base class "InterfaceBase". It stores all
    connected interfaces in a list of InterfaceBase pointers, e.g. TQPtrList.
